@@ -403,6 +403,13 @@ public:
     void visitClassStatement(ClassStatementAst *node) override
     {
         printToken(node, QStringLiteral("classStatement"));
+        if (node->variable) printToken(node->variable, QStringLiteral("classVariableDeclaration"), QStringLiteral("variable"));
+        if (node->modifiers) printToken(node->modifiers, QStringLiteral("optionalModifiers"), QStringLiteral("modifiers"));
+        if (node->propertyType) printToken(node->propertyType, QStringLiteral("propertyType"), QStringLiteral("propertyType"));
+        if (node->methodName) printToken(node->methodName, QStringLiteral("semiReservedIdentifier"), QStringLiteral("methodName"));
+        if (node->parameters) printToken(node->parameters, QStringLiteral("parameterList"), QStringLiteral("parameters"));
+        if (node->returnType) printToken(node->returnType, QStringLiteral("returnType"), QStringLiteral("returnType"));
+        if (node->methodBody) printToken(node->methodBody, QStringLiteral("methodBody"), QStringLiteral("methodBody"));
         if (node->constsSequence)
         {
             const KDevPG::ListNode<ClassConstantDeclarationAst*> *__it = node->constsSequence->front(), *__end = __it;
@@ -413,12 +420,6 @@ public:
             }
             while (__it != __end);
         }
-        if (node->variable) printToken(node->variable, QStringLiteral("classVariableDeclaration"), QStringLiteral("variable"));
-        if (node->modifiers) printToken(node->modifiers, QStringLiteral("optionalModifiers"), QStringLiteral("modifiers"));
-        if (node->methodName) printToken(node->methodName, QStringLiteral("semiReservedIdentifier"), QStringLiteral("methodName"));
-        if (node->parameters) printToken(node->parameters, QStringLiteral("parameterList"), QStringLiteral("parameters"));
-        if (node->returnType) printToken(node->returnType, QStringLiteral("returnType"), QStringLiteral("returnType"));
-        if (node->methodBody) printToken(node->methodBody, QStringLiteral("methodBody"), QStringLiteral("methodBody"));
         if (node->traitsSequence)
         {
             const KDevPG::ListNode<NamespacedIdentifierAst*> *__it = node->traitsSequence->front(), *__end = __it;
@@ -1193,6 +1194,24 @@ public:
         m_indent--;
     }
 
+    void visitPropertyType(PropertyTypeAst *node) override
+    {
+        printToken(node, QStringLiteral("propertyType"));
+        if (node->typehint) printToken(node->typehint, QStringLiteral("propertyTypeHint"), QStringLiteral("typehint"));
+        ++m_indent;
+        DefaultVisitor::visitPropertyType(node);
+        m_indent--;
+    }
+
+    void visitPropertyTypeHint(PropertyTypeHintAst *node) override
+    {
+        printToken(node, QStringLiteral("propertyTypeHint"));
+        if (node->genericType) printToken(node->genericType, QStringLiteral("namespacedIdentifier"), QStringLiteral("genericType"));
+        ++m_indent;
+        DefaultVisitor::visitPropertyTypeHint(node);
+        m_indent--;
+    }
+
     void visitRelationalExpression(RelationalExpressionAst *node) override
     {
         printToken(node, QStringLiteral("relationalExpression"));
@@ -1420,16 +1439,7 @@ public:
             }
             while (__it != __end);
         }
-        if (node->useNamespaceSequence)
-        {
-            const KDevPG::ListNode<UseNamespaceAst*> *__it = node->useNamespaceSequence->front(), *__end = __it;
-            do
-            {
-                printToken(__it->element, QStringLiteral("useNamespace"), QStringLiteral("useNamespace[]"));
-                __it = __it->next;
-            }
-            while (__it != __end);
-        }
+        if (node->useStatement) printToken(node->useStatement, QStringLiteral("useStatement"), QStringLiteral("useStatement"));
         ++m_indent;
         DefaultVisitor::visitStatement(node);
         m_indent--;
@@ -1675,6 +1685,24 @@ public:
         m_indent--;
     }
 
+    void visitUseStatement(UseStatementAst *node) override
+    {
+        printToken(node, QStringLiteral("useStatement"));
+        if (node->useNamespaceSequence)
+        {
+            const KDevPG::ListNode<UseNamespaceAst*> *__it = node->useNamespaceSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("useNamespace"), QStringLiteral("useNamespace[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
+        ++m_indent;
+        DefaultVisitor::visitUseStatement(node);
+        m_indent--;
+    }
+
     void visitVarExpression(VarExpressionAst *node) override
     {
         printToken(node, QStringLiteral("varExpression"));
